Documentation
¶
Index ¶
- Variables
- func Alert(msg string) string
- func Black(a ...any) string
- func BlackBg(a ...any) string
- func BlackBgf(format string, a ...any) string
- func Blackf(format string, a ...any) string
- func Blue(a ...any) string
- func BlueBg(a ...any) string
- func BlueBgf(format string, a ...any) string
- func Bluef(format string, a ...any) string
- func Complete(msg string) string
- func Cyan(a ...any) string
- func CyanBg(a ...any) string
- func CyanBgf(format string, a ...any) string
- func Cyanf(format string, a ...any) string
- func Fail(msg string) string
- func Green(a ...any) string
- func GreenBg(a ...any) string
- func GreenBgf(format string, a ...any) string
- func Greenf(format string, a ...any) string
- func Info(msg string) string
- func Magenta(a ...any) string
- func MagentaBg(a ...any) string
- func MagentaBgf(format string, a ...any) string
- func Magentaf(format string, a ...any) string
- func Red(a ...any) string
- func RedAlert(msg string) string
- func RedBg(a ...any) string
- func RedBgf(format string, a ...any) string
- func Redf(format string, a ...any) string
- func Var(variable string, value string) string
- func VarQuote(variable string, value string) string
- func White(a ...any) string
- func WhiteBg(a ...any) string
- func WhiteBgf(format string, a ...any) string
- func Whitef(format string, a ...any) string
- func Yellow(a ...any) string
- func YellowBg(a ...any) string
- func YellowBgf(format string, a ...any) string
- func Yellowf(format string, a ...any) string
Constants ¶
This section is empty.
Variables ¶
var ( // IconComplete is the icon for a completed message. IconComplete = "[✓] " // IconAlert is the icon for an alerted message. IconAlert = "[!] " // IconFailed is the icon for a failed message. IconFailed = "[✗] " // IconInfo is the icon for an informational message. IconInfo = "[i] " )
Functions ¶
func Black ¶
Black formats using the default formats for its operands and returns the resulting string with a black foreground. Spaces are added between operands when neither is a string.
func BlackBg ¶ added in v1.1.0
BlackBg formats using the default formats for its operands and returns the resulting string with a black background. Spaces are added between operands when neither is a string.
func BlackBgf ¶ added in v1.1.0
BlackBgf formats according to a format specifier and returns the resulting string with a black background.
func Blackf ¶
Blackf formats according to a format specifier and returns the resulting string with a black foreground.
func Blue ¶
Blue formats using the default formats for its operands and returns the resulting string with a blue foreground. Spaces are added between operands when neither is a string.
func BlueBg ¶ added in v1.1.0
BlueBg formats using the default formats for its operands and returns the resulting string with a blue background. Spaces are added between operands when neither is a string.
func BlueBgf ¶ added in v1.1.0
BlueBgf formats according to a format specifier and returns the resulting string with a blue background.
func Bluef ¶
Bluef formats according to a format specifier and returns the resulting string with a blue foreground.
func Cyan ¶
Cyan formats using the default formats for its operands and returns the resulting string with a cyan foreground. Spaces are added between operands when neither is a string.
func CyanBg ¶ added in v1.1.0
CyanBg formats using the default formats for its operands and returns the resulting string with a cyan background. Spaces are added between operands when neither is a string.
func CyanBgf ¶ added in v1.1.0
CyanBgf formats according to a format specifier and returns the resulting string with a cyan background.
func Cyanf ¶
Cyanf formats according to a format specifier and returns the resulting string with a cyan foreground.
func Green ¶
Green formats using the default formats for its operands and returns the resulting string with a green foreground. Spaces are added between operands when neither is a string.
func GreenBg ¶ added in v1.1.0
GreenBg formats using the default formats for its operands and returns the resulting string with a green background. Spaces are added between operands when neither is a string.
func GreenBgf ¶ added in v1.1.0
GreenBgf formats according to a format specifier and returns the resulting string with a green background.
func Greenf ¶
Greenf formats according to a format specifier and returns the resulting string with a green foreground.
func Magenta ¶
Magenta formats using the default formats for its operands and returns the resulting string with a magenta foreground. Spaces are added between operands when neither is a string.
func MagentaBg ¶ added in v1.1.0
MagentaBg formats using the default formats for its operands and returns the resulting string with a magenta background. Spaces are added between operands when neither is a string.
func MagentaBgf ¶ added in v1.1.0
MagentaBgf formats according to a format specifier and returns the resulting string with a magenta background.
func Magentaf ¶
Magentaf formats according to a format specifier and returns the resulting string with a magenta foreground.
func Red ¶
Red formats using the default formats for its operands and returns the resulting string with a red foreground. Spaces are added between operands when neither is a string.
func RedBg ¶ added in v1.1.0
RedBg formats using the default formats for its operands and returns the resulting string with a red background. Spaces are added between operands when neither is a string.
func RedBgf ¶ added in v1.1.0
RedBgf formats according to a format specifier and returns the resulting string with a red background.
func Redf ¶
Redf formats according to a format specifier and returns the resulting string with a red foreground.
func White ¶
White formats using the default formats for its operands and returns the resulting string with a white foreground. Spaces are added between operands when neither is a string.
func WhiteBg ¶ added in v1.1.0
WhiteBg formats using the default formats for its operands and returns the resulting string with a white background. Spaces are added between operands when neither is a string.
func WhiteBgf ¶ added in v1.1.0
WhiteBgf formats according to a format specifier and returns the resulting string with a white background.
func Whitef ¶
Whitef formats according to a format specifier and returns the resulting string with a white foreground.
func Yellow ¶
Yellow formats using the default formats for its operands and returns the resulting string with a yellow foreground. Spaces are added between operands when neither is a string.
func YellowBg ¶ added in v1.1.0
YellowBg formats using the default formats for its operands and returns the resulting string with a yellow background. Spaces are added between operands when neither is a string.
Types ¶
This section is empty.